@@ -1,4 +1,3 @@
-from __future__ import print_function
 import inspect
 import shlex
 import textwrap
@@ -33,7 +32,8 @@ class CometPluginCommand(object):
 
 def map_parameters(arguments, *args):
     """
-    This command is useful to map parameters with -- to regular argument dicts for easier processing.
+    This command is useful to map parameters with -- to regular argument dicts
+    for easier processing.
 
     :param arguments:
     :param args:
@@ -96,8 +96,8 @@ def command(func):
             # pprint(argv)
             arguments = dotdict(docopt(doc, help=True, argv=argv))
             # pprint(arguments)
-            verbose = int(Variables()["verbose"] or 0)
-            #if verbose > 9:
+            # verbose = int(Variables()["verbose"] or 0)
+            # if verbose > 9:
             #    s = pformat(arguments)
             #    banner(s, label="Arguments", color="BLUE")
             func(instance, args, arguments)
@@ -110,18 +110,20 @@ def command(func):
 
                 usage = textwrap.dedent(doc.split("Usage:")[1])
                 print()
-                print ("Usage:")
+                print("Usage:")
 
-                for line in usage.split("\n"):
+                for line in usage.splitlines():
                     if ":" in line:
                         kind = line.split(":")[0]
-                        if kind in ["Arguments", "Options", "Example", "Descriptiom"]:
+                        if kind in ["Arguments", "Options", "Example",
+                                    "Descriptiom"]:
                             break
                     print(line)
-                Console.error("Could not execute the command. Please check usage with")
-                print ()
+                Console.error(
+                    "Could not execute the command. Please check usage with")
+                print()
                 Console.msg("    cms help", name.replace("do_", ""))
-                print ()
+                print()
                 # print (args)
                 # print(e)
                 # print(doc)
@@ -168,10 +170,11 @@ def basecommand(func):
             func(instance, args, arguments)
         # except docopt.DocoptExit as e:
         except Exception as e:
-            import traceback, sys
+            import traceback
+            import sys
             traceback.print_exc(file=sys.stdout)
             if args not in ('-h', '--help'):
-                print (args)
+                print(args)
                 Console.error("Could not execute the command.")
                 Console.error("Check usage..")
             print(doc)
